@@ -336,6 +336,9 @@ class App:
             toggle_repo_map_func=self.toggle_repo_map,
             get_repo_map_str_func=self._get_current_repo_map_string,
             suggest_files_func=self._ask_llm_for_files_based_on_context,
+            add_repomap_exclusion_func=self.repo_map.add_user_exclusion,
+            remove_repomap_exclusion_func=self.repo_map.remove_user_exclusion,
+            get_repomap_exclusions_func=self.repo_map.get_user_exclusions,
         )
         self.logger.debug("CommandHandler initialized.")
 
@@ -920,19 +923,57 @@ class App:
 
     def run(self):
         """Main loop for the chat application."""
-        # Determine repo map status string
-        repo_map_status = "Enabled" if self.include_repo_map else "Disabled"
+        # Determine repo map status string with more detail
+        repo_map_status_output_str: str
+        if self.include_repo_map:
+            user_exclusions = self.repo_map.get_user_exclusions()
+            if user_exclusions:
+                num_exclusions = len(user_exclusions)
+                exclusions_details = f"with {num_exclusions} exclusion"
+                if num_exclusions > 1:
+                    exclusions_details += "s"
+                # Using YELLOW for enabled with exclusions
+                repo_map_status_output_str = f"{FmtColors['YELLOW']}{STYLES['BOLD']}Enabled ({exclusions_details}){RESET}"
+            else:
+                # Using GREEN for standard enabled (no exclusions)
+                repo_map_status_output_str = f"{FmtColors['GREEN']}{STYLES['BOLD']}Enabled{RESET}"
+        else:
+            # Using default terminal color (bolded) for disabled
+            repo_map_status_output_str = f"{STYLES['BOLD']}Disabled{RESET}"
         
         # Use FmtColors and STYLES for the welcome message
         # Apply specific color (GREEN) before BOLD, then RESET immediately after.
         # The rest of the message will use the default INFO format (terminal default color).
-        self.logger.info(
-            f"Welcome to {FmtColors['GREEN']}{STYLES['BOLD']}{APP_NAME}{RESET}! "
-            f"Model: {FmtColors['GREEN']}{STYLES['BOLD']}{self.model}{RESET}. "
-            f"Repo Map: {FmtColors['BLUE']}{STYLES['BOLD']}{repo_map_status}{RESET}. "
-            f"Type /help for commands, !<cmd> to run shell commands.",
-        )
+        
+        # Constructing the welcome message parts
+        model_line = f"  Model: {FmtColors['GREEN']}{STYLES['BOLD']}{self.model}{RESET}"
+        repo_map_line = f"  Repo Map: {repo_map_status_output_str}"
 
+        # Active Rules status
+        num_active_rules = len(self.rule_manager.last_loaded_rule_names)
+        active_rules_names_sorted = sorted(list(self.rule_manager.last_loaded_rule_names))
+        
+        active_rules_status_output_str: str
+        if num_active_rules > 0:
+            max_names_to_show = 2 # Be concise for welcome message
+            names_str = ", ".join(active_rules_names_sorted[:max_names_to_show])
+            if num_active_rules > max_names_to_show:
+                names_str += f", ... ({num_active_rules - max_names_to_show} more)"
+            
+            active_rules_status_output_str = f"{FmtColors['GREEN']}{STYLES['BOLD']}Enabled ({num_active_rules}){RESET} [{names_str}]"
+        else:
+            # Using default terminal color (bolded) for none
+            active_rules_status_output_str = f"{STYLES['BOLD']}None{RESET}"
+        
+        active_rules_line = f"  Rules: {active_rules_status_output_str}"
+        help_line = f"  Type {FmtColors['CYAN']}{STYLES['BOLD']}/help{RESET} for commands, or {FmtColors['CYAN']}{STYLES['BOLD']}!<cmd>{RESET} to run shell commands. \n"
+
+        # Log each part on a new line for clarity
+        self.logger.info(model_line)
+        self.logger.info(repo_map_line)
+        self.logger.info(active_rules_line)
+        self.logger.info(help_line)
+        
         ctrl_c_pressed_once = False # Initialize flag outside the loop
         while True:
             try:
